========================
Release Notes
========================

.. changelog::
    :changelog-url: https://fastmachinelearning.org/hls4ml/release_notes.html
    :github: https://github.com/fastmachinelearning/hls4ml/releases/
    :pypi: https://pypi.org/project/hls4ml/
